@@ -21,6 +21,7 @@
 #include "copycd.h"
 #include "mastercd.h"
 #include "audiocd.h"
+#include "cddata.h"
 
 KOnCD::KOnCD(QWidget *parent, const char *name) : KOnCD_MainWindow(parent, name){
 	setupMenubar();
@@ -33,18 +34,21 @@ KOnCD::~KOnCD(){
 void KOnCD::setupMenubar(){
 
 	// KOnCD-menu entries
-	KPopupMenu *p = new KPopupMenu;
+	KPopupMenu *popupMenu1 = new KPopupMenu;
+	KPopupMenu *popupMenu2 = new KPopupMenu;
 
-	p->insertItem( i18n( "&Setup" ), this, SLOT( slot_setup() ) );
-	p->insertSeparator();
-	p->insertItem( i18n( "&Copy CD" ), this, SLOT( slot_copyCD() ) );
-	p->insertItem( i18n( "&Master CD" ), this, SLOT( slot_masterCD() ) );
-	p->insertItem( i18n( "&Audio CD" ), this, SLOT( slot_audioCD() ) );
-	p->insertSeparator();
-	p->insertItem( i18n( "&Tools" ), this, SLOT( slot_tools() ) );
-	p->insertItem( i18n( "&Image Type" ), this, SLOT( slot_image_type() ) );
-	p->insertSeparator();
-	p->insertItem( i18n( "&Quit" ), this, SLOT( slot_exitApp() ), CTRL+Key_Q);
+	popupMenu1->insertItem( i18n( "&Copy CD" ), this, SLOT( slot_copyCD() ) );
+	popupMenu1->insertItem( i18n( "&Master CD" ), this, SLOT( slot_masterCD() ) );
+	popupMenu1->insertItem( i18n( "&Audio CD" ), this, SLOT( slot_audioCD() ) );
+	popupMenu1->insertSeparator();
+	popupMenu1->insertItem( i18n( "&Quit" ), this, SLOT( slot_exitApp() ), CTRL+Key_Q);
+
+	popupMenu2->insertItem( i18n( "&Setup" ), this, SLOT( slot_setup() ) );
+	popupMenu2->insertSeparator();
+	popupMenu2->insertItem( i18n( "&Tools" ), this, SLOT( slot_tools() ) );
+	popupMenu2->insertItem( i18n( "&Image Type" ), this, SLOT( slot_image_type() ) );
+	popupMenu2->insertSeparator();
+	popupMenu2->insertItem( i18n( "&Reset Devices" ), this, SLOT( slot_resetDevices() ), CTRL+Key_R );
 
 	// Help-menu entries
   const KAboutData *aboutData = KGlobal::instance()->aboutData();
@@ -53,10 +57,17 @@ void KOnCD::setupMenubar(){
 
 	// Insert menu
 	KMenuBar *menubar = new KMenuBar( this );
-	menubar->insertItem( i18n( "K&OnCD" ), p);
+	menubar->insertItem( i18n( "K&OnCD" ), popupMenu1);
+	menubar->insertItem( i18n( "T&ools" ), popupMenu2);
 	menubar->insertItem( i18n( "&Help" ), help);
 }
 
+// 'Reset all devices' clicked
+void KOnCD::slot_resetDevices(){
+	CDdata *CD = new CDdata;
+	CD->reset( 0 );
+}
+
 // 'Setup' clicked
 void KOnCD::slot_setup(){
 	Setup* dlg = new Setup;
