@@ -81,6 +81,10 @@ MasterCD::MasterCD(QWidget *parent, const char *name ) : MasterCD_GUI(parent,nam
 }
 
 MasterCD::~MasterCD(){
+	existsSession = false;
+	MS_Start = 0;
+	MS_End = 0;
+	FS_Size = 0;
 }
 
 //'SourceDir-Button' clicked
@@ -139,6 +143,8 @@ void MasterCD::slot_toggleBootableCD(){
 
 //'QCheckBox_Burn on-the-fly' clicked
 void MasterCD::slot_toggle_onthefly(){
+	QCheckBox_Multisession->setEnabled( QCheckBox_onthefly->isChecked() ? false:true );
+	QCheckBox_Multisession->setChecked( false );
 	QPushButton_ImageFile->setEnabled( QCheckBox_onthefly->isChecked() ? false:true );
 	QLineEdit_ImageFile->setEnabled( QCheckBox_onthefly->isChecked() ? false:true );
 	QLineEdit_ImageFile->setText( "" );
@@ -146,32 +152,43 @@ void MasterCD::slot_toggle_onthefly(){
 	QCheckBox_LeaveImage->setChecked( false );
 	QCheckBox_CreateImage->setEnabled( QCheckBox_onthefly->isChecked() ? false:true );
 	QCheckBox_CreateImage->setChecked( QCheckBox_onthefly->isChecked() ? false:true );
-	QCheckBox_Multisession->setEnabled( QCheckBox_onthefly->isChecked() ? false:true );
-	QCheckBox_Multisession->setChecked( false );
-	if ( QCheckBox_BootableCD->isChecked() ) QPushButton_BootImage->setEnabled( QCheckBox_onthefly->isChecked() ? false:true );
-	if ( QCheckBox_BootableCD->isChecked() ) QLineEdit_BootImage->setEnabled( QCheckBox_onthefly->isChecked() ? false:true );
-	QLineEdit_BootImage->setText( "" );
 	QCheckBox_BootableCD->setEnabled( QCheckBox_onthefly->isChecked() ? false:true );
 	QCheckBox_BootableCD->setChecked( false );
-	QCheckBox_nofix->setEnabled( QCheckBox_onthefly->isChecked() ? false:true );
+	if ( ! QCheckBox_nofix->isEnabled() ) QCheckBox_nofix->setEnabled( true );
+	if ( QCheckBox_BootableCD->isChecked() ){
+		QPushButton_BootImage->setEnabled( false );
+		QLineEdit_BootImage->setEnabled( false );
+		QLineEdit_BootImage->setText( "" );
+	}
 }
 
 //'QCheckBox_WriteCD' clicked
 void MasterCD::slot_toggleWriteCD(){
 	QCheckBox_EjectCD->setEnabled( QCheckBox_WriteCD->isChecked() ? true:false );
+	QCheckBox_EjectCD->setChecked( false );
 	QCheckBox_nofix->setEnabled( QCheckBox_WriteCD->isChecked() ? true:false );
+	QCheckBox_nofix->setChecked( false );
 	QCheckBox_Simulate->setEnabled( QCheckBox_WriteCD->isChecked() ? true:false );
+	QCheckBox_Simulate->setChecked( false );
 	QCheckBox_Force->setEnabled( QCheckBox_WriteCD->isChecked() ? true:false );
+	QCheckBox_Force->setChecked( false );
 	QCheckBox_ignoresize->setEnabled( QCheckBox_WriteCD->isChecked() ? true:false );
+	QCheckBox_ignoresize->setChecked( false );
+	QCheckBox_LeaveImage->setChecked( false );
 	if ( ! QCheckBox_onthefly->isChecked() ) QCheckBox_LeaveImage->setEnabled( QCheckBox_WriteCD->isChecked() ? true:false );
 }
 
 //'QCheckBox_CreateImage' clicked
 void MasterCD::slot_toggleCreateImage(){
 	QCheckBox_BootableCD->setEnabled( QCheckBox_CreateImage->isChecked() ? true:false );
+	QCheckBox_BootableCD->setChecked( false );
+	QPushButton_BootImage->setEnabled( false );
+	QLineEdit_BootImage->setEnabled( false );
+	QLineEdit_BootImage->setText( "" );
 	QListBox_SourceDirs->setEnabled( QCheckBox_CreateImage->isChecked() ? true:false );
 	QListBox_SourceDirs->clear();
 	QPushButton_SourceDir->setEnabled( QCheckBox_CreateImage->isChecked() ? true:false );
+	QPushButton_DeleteTrack->setEnabled( QCheckBox_CreateImage->isChecked() ? true:false );
 }
 
 //'QCheckBox_Multisession' clicked
@@ -321,7 +338,6 @@ void MasterCD::slot_makeImage(){
 
 //---Write CD with cdrecord---
 void MasterCD::slot_writeCD(){
-	int rc;
 	KConfig *config = kapp->config();
 
 	//KProcess argument
@@ -334,7 +350,7 @@ void MasterCD::slot_writeCD(){
 	(*process) << config->readEntry("Device");
 
 	//Set Burn-Proof
-	if( config->readNumEntry("BurnProof") == true ) (*process) << "driveropts=burnproof";
+	if( config->readBoolEntry("BurnProof") ) (*process) << "driveropts=burnproof";
 
 	//Set CD-Writer Options to KProcess
 	if( QCheckBox_EjectCD->isChecked() ) (*process) << "-eject";
@@ -345,30 +361,46 @@ void MasterCD::slot_writeCD(){
 	if( QCheckBox_ignoresize->isChecked() ) (*process) << "-ignsize";
 
 	//Set CD-RW Options to KProcess
-	if( (rc = QComboBox_CDRWBlanking -> currentItem()) )
-		{
-	   	if( rc == 1 ) (*process) << "blank=all";
-	   	if( rc == 2 ) (*process) << "blank=fast";
-	   	if( rc == 3 ) (*process) << "blank=track";
-	   	if( rc == 4 ) (*process) << "blank=unreserve";
-	   	if( rc == 5 ) (*process) << "blank=trtrail";
-	   	if( rc == 6 ) (*process) << "blank=unclose";
-	   	if( rc == 7 ) (*process) << "blank=session";
-	   	}
+	switch( QComboBox_CDRWBlanking->currentItem() )
+	{
+	 	case 1:	(*process) << "blank=all";
+						break;
+	 	case 2: (*process) << "blank=fast";
+						break;
+	 	case 3: (*process) << "blank=track";
+						break;
+	 	case 4: (*process) << "blank=unreserve";
+						break;
+	 	case 5: (*process) << "blank=trtrail";
+						break;
+	 	case 6: (*process) << "blank=unclose";
+						break;
+		case 7: (*process) << "blank=session";
+						break;
+	}
 
-	//Set CD-Writer Speed to KProcess)
-	if( (rc = QComboBox_WriterSpeed -> currentItem()) )
-		{
-	   	if( rc == 0 ) (*process) << "speed=1";
-	   	if( rc == 1 ) (*process) << "speed=2";
-	   	if( rc == 2 ) (*process) << "speed=4";
-	   	if( rc == 3 ) (*process) << "speed=6";
-	   	if( rc == 4 ) (*process) << "speed=8";
-	   	if( rc == 5 ) (*process) << "speed=10";
-	   	if( rc == 6 ) (*process) << "speed=12";
-	   	if( rc == 7 ) (*process) << "speed=16";
-	   	if( rc == 8 ) (*process) << "speed=20";
-	   	}
+	//Set CD-Writer Speed to KProcess
+	switch( QComboBox_WriterSpeed -> currentItem() )
+	{
+   	case 0:	(*process) << "speed=1";
+						break;
+   	case 1:	(*process) << "speed=2";
+						break;
+   	case 2:	(*process) << "speed=4";
+						break;
+   	case 3:	(*process) << "speed=6";
+						break;
+   	case 4:	(*process) << "speed=8";
+						break;
+   	case 5:	(*process) << "speed=10";
+						break;
+   	case 6:	(*process) << "speed=12";
+						break;
+   	case 7:	(*process) << "speed=16";
+						break;
+   	case 8:	(*process) << "speed=20";
+						break;
+	}
 
 	//Set the Image
 	(*process) << QLineEdit_ImageFile->text();
@@ -483,20 +515,6 @@ void MasterCD::slot_writeCD_onthefly(){
 	if ( config->readBoolEntry( "HideTRANS_TBLfiles" ) ) (*shellProcess) << "-hide-joliet-trans-tbl";
 	if ( config->readBoolEntry( "Untranslatedfiles" ) ) (*shellProcess) << "-U";
 
-	//Arguments for multisession
-	if ( QCheckBox_Multisession->isChecked() && existsSession == true ) {
-		char tmp[50], dev[10], outdev[10];
-		char *tmpdev;
-		sprintf( tmp, "%d,%d", MS_Start, MS_End );
-	 	(*shellProcess) << "-C" << tmp;
-		config->setGroup("CD-Writer");
-		strcpy(dev, config->readEntry("Device"));
-		printf("%s\n", strtok(dev, "="));
-		while ( (tmpdev=strtok(NULL, "=")) != NULL)
-		strcpy(outdev, tmpdev);
-		(*shellProcess) << "-M" << outdev;
-	}
-
 	//Add CD-Identification
 	if( QLineEdit_VolumeID->text() ){
 		QString volumeid;
@@ -550,42 +568,56 @@ void MasterCD::slot_writeCD_onthefly(){
 	(*shellProcess) << config->readEntry("Device");
 
 	//Set Burn-Proof
-	if( config->readNumEntry("BurnProof") == true ) (*shellProcess) << "driveropts=burnproof";
+	if( config->readBoolEntry("BurnProof") ) (*shellProcess) << "driveropts=burnproof";
 
 	//Set CD-Writer Options to KProcess
 	if( QCheckBox_EjectCD->isChecked() ) (*shellProcess) << "-eject";
 	if( QCheckBox_Force->isChecked() ) (*shellProcess) << "-force";
-	if( QCheckBox_Multisession->isChecked() ) (*shellProcess) << "-multi";
 	if( QCheckBox_Simulate->isChecked() ) (*shellProcess) << "-dummy";
 	if( QCheckBox_nofix->isChecked() ) (*shellProcess) << "-nofix";
 	if( QCheckBox_ignoresize->isChecked() ) (*shellProcess) << "-ignsize";
 
-	//Set CD-RW Options to 	int Kprocess
-	int rc;
-	if( (rc = QComboBox_CDRWBlanking -> currentItem()) )
-		{
-	   	if( rc == 1 ) (*shellProcess) << "blank=all";
-	   	if( rc == 2 ) (*shellProcess) << "blank=fast";
-	   	if( rc == 3 ) (*shellProcess) << "blank=track";
-	   	if( rc == 4 ) (*shellProcess) << "blank=unreserve";
-	   	if( rc == 5 ) (*shellProcess) << "blank=trtrail";
-	   	if( rc == 6 ) (*shellProcess) << "blank=unclose";
-	   	if( rc == 7 ) (*shellProcess) << "blank=session";
-	   	}
+	//Set CD-RW Options to KProcess
+	switch( QComboBox_CDRWBlanking->currentItem() )
+	{
+	 	case 1:	(*shellProcess) << "blank=all";
+						break;
+	 	case 2: (*shellProcess) << "blank=fast";
+						break;
+	 	case 3: (*shellProcess) << "blank=track";
+						break;
+	 	case 4: (*shellProcess) << "blank=unreserve";
+						break;
+	 	case 5: (*shellProcess) << "blank=trtrail";
+						break;
+	 	case 6: (*shellProcess) << "blank=unclose";
+						break;
+		case 7: (*shellProcess) << "blank=session";
+						break;
+	}
 
-	//Set CD-Writer Speed to Kprocess
-	if( (rc = QComboBox_WriterSpeed -> currentItem()) )
-		{
-	   	if( rc == 0 ) (*shellProcess) << "speed=1";
-	   	if( rc == 1 ) (*shellProcess) << "speed=2";
-	   	if( rc == 2 ) (*shellProcess) << "speed=4";
-	   	if( rc == 3 ) (*shellProcess) << "speed=6";
-	   	if( rc == 4 ) (*shellProcess) << "speed=8";
-	   	if( rc == 5 ) (*shellProcess) << "speed=10";
-	   	if( rc == 6 ) (*shellProcess) << "speed=12";
-	   	if( rc == 7 ) (*shellProcess) << "speed=16";
-	   	if( rc == 8 ) (*shellProcess) << "speed=20";
-	   	}
+	//Set CD-Writer Speed to KProcess
+	switch( QComboBox_WriterSpeed -> currentItem() )
+	{
+   	case 0:	(*shellProcess) << "speed=1";
+						break;
+   	case 1:	(*shellProcess) << "speed=2";
+						break;
+   	case 2:	(*shellProcess) << "speed=4";
+						break;
+   	case 3:	(*shellProcess) << "speed=6";
+						break;
+   	case 4:	(*shellProcess) << "speed=8";
+						break;
+   	case 5:	(*shellProcess) << "speed=10";
+						break;
+   	case 6:	(*shellProcess) << "speed=12";
+						break;
+   	case 7:	(*shellProcess) << "speed=16";
+						break;
+   	case 8:	(*shellProcess) << "speed=20";
+						break;
+	}
 
 	//Set filesystem size
 	sprintf( tmp, "tsize=%d", FS_Size );
@@ -838,8 +870,8 @@ void MasterCD::slot_MSInfo() {
 	//Start KProcess
 	if( ! process->start( KProcess::NotifyOnExit, KProcess::AllOutput ) ) KMessageBox::error( 0, i18n("MSInfo:\nCould not start cdrecord !") );
 
-	imgprocoutdlg.StatusLabel -> setText( i18n("Retrieve multisession info...") );
-	imgprocoutdlg.show();
+	imgprocoutdlg.StatusLabel -> setText( i18n( "Retrieve multisession info..." ) );
+	if ( ! imgprocoutdlg.isVisible() ) imgprocoutdlg.show();
 }
 
 //KProcess Analyse for msinfo output
@@ -853,10 +885,11 @@ void MasterCD::slot_MSOutput( KProcess *, char *s, int n ){
 
 	//Check for exists session
 	if( strstr( buf, "status: 0x2 (CHECK CONDITION)" )) {
-		imgprocoutdlg.StatusLabel -> setText( i18n( "None session available, creating image..." ) );
+		imgprocoutdlg.StatusLabel->setText( i18n( "None session available, creating image..." ) );
 		existsSession = false;
   }
 	else {
+		imgprocoutdlg.StatusLabel->setText( i18n( "Session available, creating image..." ) );
 		existsSession = true;
 	}
 
@@ -932,7 +965,7 @@ void MasterCD::slot_PrintSize() {
 	if( ! process->start( KProcess::NotifyOnExit, KProcess::AllOutput ) ) KMessageBox::error( 0, i18n("PrintSize:\nCould not start cdrecord !") );
 
 	procoutdlg.StatusLabel -> setText( i18n("Retrieve filesystem size...") );
-	procoutdlg.show();
+	if ( ! procoutdlg.isVisible() ) procoutdlg.show();
 }
 
 //KProcess Analyse for print-size
@@ -976,8 +1009,8 @@ void MasterCD::slot_PrintSizeExited(KProcess *rcproc) {
 				procoutdlg.QPushButton_OK->setText( "&OK" );
 				return;
 			}
-	//Write CD on-the-fly
-	slot_writeCD_onthefly();
+		//Write CD on-the-fly
+		slot_writeCD_onthefly();
 	}
 }
 
