@@ -45,7 +45,6 @@ void Tools::slot_deviceReset(){
 
 //---Start cdrecord---
 void Tools::slot_start(){
-	int rc;
 	KConfig* config = kapp->config();
 
 	QPushButton_Start->setEnabled( false );
@@ -64,30 +63,46 @@ void Tools::slot_start(){
 	if( QCheckBox_generateTOC->isChecked() ) process << "-fix";
 
 	//Set CD-RW Options to KProcess
-	if( (rc = QComboBox_CDRWBlanking -> currentItem()) )
-		{
-	   	if( rc == 1 ) process << "blank=all";
-	   	if( rc == 2 ) process << "blank=fast";
-	   	if( rc == 3 ) process << "blank=track";
-	   	if( rc == 4 ) process << "blank=unreserve";
-	   	if( rc == 5 ) process << "blank=trtrail";
-	   	if( rc == 6 ) process << "blank=unclose";
-	   	if( rc == 7 ) process << "blank=session";
-	   	}
+	switch( QComboBox_CDRWBlanking->currentItem() )
+	{
+	 	case 1:	process << "blank=all";
+						break;
+	 	case 2: process << "blank=fast";
+						break;
+	 	case 3: process << "blank=track";
+						break;
+	 	case 4: process << "blank=unreserve";
+						break;
+	 	case 5: process << "blank=trtrail";
+						break;
+	 	case 6: process << "blank=unclose";
+						break;
+		case 7: process << "blank=session";
+						break;
+	}
 
 	//Set CD-Writer Speed to KProcess
-	if( (rc = QComboBox_WriterSpeed -> currentItem()) )
-		{
-	   	if( rc == 0 ) process << "speed=1";
-	   	if( rc == 1 ) process << "speed=2";
-	   	if( rc == 2 ) process << "speed=4";
-	   	if( rc == 3 ) process << "speed=6";
-	   	if( rc == 4 ) process << "speed=8";
-	   	if( rc == 5 ) process << "speed=10";
-	   	if( rc == 6 ) process << "speed=12";
-	   	if( rc == 7 ) process << "speed=16";
-	   	if( rc == 8 ) process << "speed=20";
-	   	}
+	switch( QComboBox_WriterSpeed -> currentItem() )
+	{
+   	case 0:	process << "speed=1";
+						break;
+   	case 1:	process << "speed=2";
+						break;
+   	case 2:	process << "speed=4";
+						break;
+   	case 3:	process << "speed=6";
+						break;
+   	case 4:	process << "speed=8";
+						break;
+   	case 5:	process << "speed=10";
+						break;
+   	case 6:	process << "speed=12";
+						break;
+   	case 7:	process << "speed=16";
+						break;
+   	case 8:	process << "speed=20";
+						break;
+	}
 
 	StatusLabel -> setText( i18n("Prepare for write...") );
 
